@@ -189,7 +189,7 @@ def baseml_demo():
     ml = wf(task='baseml',checkpoint="baseml_ckpt.pkl") # iris act 
     # result = ml.inference(data=[[1,0.5,-1,0]])
     # result = ml.inference(data=[1,0.5,-1,0])
-    result = ml.inference(data=[0.5])
+    result = ml.inference(data=np.array([[0.5,0,1,1]]))
 
 
     re = ml.format_output(lang="zh")
@@ -394,6 +394,13 @@ def openvino_demo():
 
     print(result)
 
+def color_demo():
+    from XEdu.hub import Workflow as wf
+    color = wf(task='gen_color',download_path='new_download')# ,checkpoint='/home/user/下载/colorization-master/colorizer_siggraph17.onnx')
+    img = cv2.imread('/home/user/下载/colorization-master/imgs/ansel_adams3.jpg')
+    result = color.inference(data='/home/user/下载/colorization-master/imgs/ansel_adams3.jpg',img_type='pil')
+    color.save(result,"color_ou.jpg")
+
 
 if __name__ == "__main__":
     # pose_infer_demo()
@@ -408,11 +415,16 @@ if __name__ == "__main__":
     # custom_demo()
     # basenn_demo()
     # cls_demo()
-    baseml_demo()
+    # baseml_demo()
     # style_demo()
     # qa_demo()
     # drive_demo()
     # embedding_demo()
- 
+    color_demo()
+    # from openxlab.model import download
+    # download(model_repo='xedu/hub-model', model_name='gen_color.onnx')
+    # url = "https://download.openxlab.org.cn/repos/file/xedu/hub-model/main?filepath=gen_color.onnx&sign=2838feb49073bb8f756d57a9f78a68ab&nonce=1713425582020"
+    # path = "git-lfs/gen_color.onnx"
+    # downloader = Downloader(url, path)
+    # downloader.start()
 
-    
\ No newline at end of file
